@@ -458,7 +458,7 @@ class Configuration(interface.MathematicalProgrammingConfiguration):
         class WarningStreamHandler(StreamHandler):
 
             def flush(self):
-                self.logger.warn(self.getvalue())
+                self.logger.warning(self.getvalue())
 
         class LogStreamHandler(StreamHandler):
 
@@ -470,7 +470,7 @@ class Configuration(interface.MathematicalProgrammingConfiguration):
             def flush(self):
                 self.logger.debug(self.getvalue())
 
-        logger = logging.getLogger()
+        logger = logging.getLogger(__name__ + ".Model")  # TODO: Make the logger name specific to each solver instance
         logger.setLevel(logging.CRITICAL)
         error_stream_handler = ErrorStreamHandler(logger)
         warning_stream_handler = WarningStreamHandler(logger)
