@@ -33,6 +33,7 @@ import sympy
 
 import six
 
+import optlang
 from optlang.exceptions import IndicatorConstraintsNotSupported
 
 from optlang.util import parse_expr, expr_to_json, is_numeric, SolverTolerances
@@ -378,11 +379,11 @@ class OptimizationExpression(object):
         if name is None:
             return
         if len(name) < 1:
-            raise ValueError('Variable name must not be empty string')
+            raise ValueError('Name must not be empty string')
         for char in name:
             if char.isspace():
                 raise ValueError(
-                    'Variable names cannot contain whitespace characters. "%s" contains whitespace character "%s".' % (
+                    'Names cannot contain whitespace characters. "%s" contains whitespace character "%s".' % (
                         name, char)
                 )
 
@@ -463,7 +464,8 @@ class OptimizationExpression(object):
         elif isinstance(expression, int):
             return symbolics.Integer(expression)
         else:
-            # expression = expression.expand() This would be a good way to canonicalize, but is quite slow
+            if optlang._USING_SYMENGINE:
+                expression = expression.expand()  # This is a good way to canonicalize, but is quite slow for sympy
             return expression
 
     @property
@@ -1630,6 +1632,4 @@ if __name__ == '__main__':
 
     # model.remove(x1)
 
-    import optlang
-
     model.interface = optlang.glpk_interface
